@@ -24,14 +24,15 @@
 
 #include <unistd.h>
 
-#include <qtest.h>
+#include <QTest>
+#include <QTimeZone>
 QTEST_MAIN(FileStorageTest)
 
 using namespace KCalCore;
 
 void FileStorageTest::testValidity()
 {
-    MemoryCalendar::Ptr cal(new MemoryCalendar(KDateTime::UTC));
+    MemoryCalendar::Ptr cal(new MemoryCalendar(QTimeZone::utc()));
     FileStorage fs(cal, QStringLiteral("fred.ics"));
     QCOMPARE(fs.fileName(), QStringLiteral("fred.ics"));
     QCOMPARE(fs.calendar().data(), cal.data());
@@ -40,15 +41,15 @@ void FileStorageTest::testValidity()
 
 void FileStorageTest::testSave()
 {
-    MemoryCalendar::Ptr cal(new MemoryCalendar(QStringLiteral("UTC")));
+    MemoryCalendar::Ptr cal(new MemoryCalendar(QTimeZone::utc()));
     FileStorage fs(cal, QStringLiteral("fred.ics"));
 
     QDate dt = QDate::currentDate();
 
     Event::Ptr event1 = Event::Ptr(new Event());
     event1->setUid(QStringLiteral("1"));
-    event1->setDtStart(KDateTime(dt));
-    event1->setDtEnd(KDateTime(dt).addDays(1));
+    event1->setDtStart(QDateTime(dt, {}));
+    event1->setDtEnd(QDateTime(dt, {}).addDays(1));
     event1->setSummary(QStringLiteral("Event1 Summary"));
     event1->setDescription(QStringLiteral("This is a description of the first event"));
     event1->setLocation(QStringLiteral("the place"));
@@ -56,8 +57,8 @@ void FileStorageTest::testSave()
 
     Event::Ptr event2 = Event::Ptr(new Event());
     event2->setUid(QStringLiteral("2"));
-    event2->setDtStart(KDateTime(dt).addDays(1));
-    event2->setDtEnd(KDateTime(dt).addDays(2));
+    event2->setDtStart(QDateTime(dt, {}).addDays(1));
+    event2->setDtEnd(QDateTime(dt, {}).addDays(2));
     event2->setSummary(QStringLiteral("Event2 Summary"));
     event2->setDescription(QStringLiteral("This is a description of the second event"));
     event2->setLocation(QStringLiteral("the other place"));
@@ -72,15 +73,15 @@ void FileStorageTest::testSave()
 
 void FileStorageTest::testSaveLoadSave()
 {
-    MemoryCalendar::Ptr cal(new MemoryCalendar(QStringLiteral("UTC")));
+    MemoryCalendar::Ptr cal(new MemoryCalendar(QTimeZone::utc()));
     FileStorage fs(cal, QStringLiteral("fred.ics"));
 
     QDate dt = QDate::currentDate();
 
     Event::Ptr event1 = Event::Ptr(new Event());
     event1->setUid(QStringLiteral("1"));
-    event1->setDtStart(KDateTime(dt));
-    event1->setDtEnd(KDateTime(dt).addDays(1));
+    event1->setDtStart(QDateTime(dt, {}));
+    event1->setDtEnd(QDateTime(dt, {}).addDays(1));
     event1->setSummary(QStringLiteral("Event1 Summary"));
     event1->setDescription(QStringLiteral("This is a description of the first event"));
     event1->setLocation(QStringLiteral("the place"));
@@ -88,8 +89,8 @@ void FileStorageTest::testSaveLoadSave()
 
     Event::Ptr event2 = Event::Ptr(new Event());
     event2->setUid(QStringLiteral("2"));
-    event2->setDtStart(KDateTime(dt).addDays(1));
-    event2->setDtEnd(KDateTime(dt).addDays(2));
+    event2->setDtStart(QDateTime(dt, {}).addDays(1));
+    event2->setDtEnd(QDateTime(dt, {}).addDays(2));
     event2->setSummary(QStringLiteral("Event2 Summary"));
     event2->setDescription(QStringLiteral("This is a description of the second event"));
     event2->setLocation(QStringLiteral("the other place"));
@@ -118,15 +119,15 @@ void FileStorageTest::testSpecialChars()
 
     Event::Ptr event = Event::Ptr(new Event());
     event->setUid(uid);
-    event->setDtStart(KDateTime(currentDate));
-    event->setDtEnd(KDateTime(currentDate.addDays(1)));
+    event->setDtStart(QDateTime(currentDate, {}));
+    event->setDtEnd(QDateTime(currentDate.addDays(1), {}));
 
     const QChar latin1_umlaut[] = { 0xFC, QLatin1Char('\0') };
 
     event->setSummary(QString(latin1_umlaut));
 
     // Save to file:
-    MemoryCalendar::Ptr cal(new MemoryCalendar(QStringLiteral("UTC")));
+    MemoryCalendar::Ptr cal(new MemoryCalendar(QTimeZone::utc()));
     FileStorage fs(cal, QStringLiteral("bart.ics"));
     cal->addEvent(event);
 
@@ -135,7 +136,7 @@ void FileStorageTest::testSpecialChars()
     QVERIFY(fs.close());
 
     // Load again:
-    MemoryCalendar::Ptr otherCalendar(new MemoryCalendar(QStringLiteral("UTC")));
+    MemoryCalendar::Ptr otherCalendar(new MemoryCalendar(QTimeZone::utc()));
     FileStorage otherFs(otherCalendar, QStringLiteral("bart.ics"));
     QVERIFY(otherFs.open());
     QVERIFY(otherFs.load());
