@@ -30,15 +30,15 @@
 */
 #include "icalformat.h"
 #include "icalformat_p.h"
-#include "icaltimezones.h"
+#include "icaltimezones_p.h"
 #include "freebusy.h"
 #include "memorycalendar.h"
-
 #include "kcalcore_debug.h"
-#include <QSaveFile>
-#include <kbackup.h>
+#include "calendar_p.h"
 
+#include <QSaveFile>
 #include <QFile>
+#include <QTimeZone>
 
 extern "C" {
 #include <libical/ical.h>
@@ -56,14 +56,14 @@ class Q_DECL_HIDDEN KCalCore::ICalFormat::Private
 public:
     Private(ICalFormat *parent)
         : mImpl(new ICalFormatImpl(parent)),
-          mTimeSpec(KDateTime::UTC)
+          mTimeZone(QTimeZone::utc())
     {}
     ~Private()
     {
         delete mImpl;
     }
-    ICalFormatImpl *mImpl;
-    KDateTime::Spec mTimeSpec;
+    ICalFormatImpl *mImpl = nullptr;
+    QTimeZone mTimeZone;
 };
 //@endcond
 
@@ -115,7 +115,9 @@ bool ICalFormat::save(const Calendar::Ptr &calendar, const QString &fileName)
     }
 
     // Write backup file
-    KBackup::backupFile(fileName);
+    const QString backupFile = fileName + QLatin1Char('~');
+    QFile::remove(backupFile);
+    QFile::copy(fileName, backupFile);
 
     QSaveFile file(fileName);
     if (!file.open(QIODevice::WriteOnly)) {
@@ -149,25 +151,25 @@ bool ICalFormat::fromString(const Calendar::Ptr &cal, const QString &string,
 
 Incidence::Ptr ICalFormat::readIncidence(const QByteArray &string)
 {
-    static ICalTimeZones *tzCache = new ICalTimeZones(); // populated on demand further down the call chain
-
-    icalcomponent *calendar;
-
     // Let's defend const correctness until the very gates of hell^Wlibical
-    calendar = icalcomponent_new_from_string(const_cast<char *>(string.constData()));
+    icalcomponent *calendar = icalcomponent_new_from_string(const_cast<char *>(string.constData()));
     if (!calendar) {
         qCritical() << "parse error from icalcomponent_new_from_string. string=" << QString::fromLatin1(string);
         setException(new Exception(Exception::ParseErrorIcal));
         return Incidence::Ptr();
     }
 
+    ICalTimeZoneCache tzCache;
+    ICalTimeZoneParser parser(&tzCache);
+    parser.parse(calendar);
+
     Incidence::Ptr incidence;
     if (icalcomponent_isa(calendar) == ICAL_VCALENDAR_COMPONENT) {
-        incidence = d->mImpl->readOneIncidence(calendar, tzCache);
+        incidence = d->mImpl->readOneIncidence(calendar, &tzCache);
     } else if (icalcomponent_isa(calendar) == ICAL_XROOT_COMPONENT) {
         icalcomponent *comp = icalcomponent_get_first_component(calendar, ICAL_VCALENDAR_COMPONENT);
         if (comp) {
-            incidence = d->mImpl->readOneIncidence(comp, tzCache);
+            incidence = d->mImpl->readOneIncidence(comp, &tzCache);
         }
     }
 
@@ -240,7 +242,7 @@ bool ICalFormat::fromRawString(const Calendar::Ptr &cal, const QByteArray &strin
 
 Incidence::Ptr ICalFormat::fromString(const QString &string)
 {
-    MemoryCalendar::Ptr cal(new MemoryCalendar(d->mTimeSpec));
+    MemoryCalendar::Ptr cal(new MemoryCalendar(d->mTimeZone));
     fromString(cal, string);
 
     const Incidence::List list = cal->incidences();
@@ -253,66 +255,66 @@ QString ICalFormat::toString(const Calendar::Ptr &cal,
     icalcomponent *calendar = d->mImpl->createCalendarComponent(cal);
     icalcomponent *component;
 
-    ICalTimeZones *tzlist = cal->timeZones();  // time zones possibly used in the calendar
-    ICalTimeZones tzUsedList;                  // time zones actually used in the calendar
+    QVector<QTimeZone> tzUsedList;
+    TimeZoneEarliestDate earliestTz;
 
     // todos
     Todo::List todoList = deleted ? cal->deletedTodos() : cal->rawTodos();
-    Todo::List::ConstIterator it;
-    for (it = todoList.constBegin(); it != todoList.constEnd(); ++it) {
+    for (auto it = todoList.cbegin(), end = todoList.cend(); it != end; ++it) {
         if (!deleted || !cal->todo((*it)->uid(), (*it)->recurrenceId())) {
             // use existing ones, or really deleted ones
             if (notebook.isEmpty() ||
                     (!cal->notebook(*it).isEmpty() && notebook.endsWith(cal->notebook(*it)))) {
-                component = d->mImpl->writeTodo(*it, tzlist, &tzUsedList);
+                component = d->mImpl->writeTodo(*it, &tzUsedList);
                 icalcomponent_add_component(calendar, component);
+                ICalTimeZoneParser::updateTzEarliestDate((*it), &earliestTz);
             }
         }
     }
     // events
     Event::List events = deleted ? cal->deletedEvents() : cal->rawEvents();
-    Event::List::ConstIterator it2;
-    for (it2 = events.constBegin(); it2 != events.constEnd(); ++it2) {
-        if (!deleted || !cal->event((*it2)->uid(), (*it2)->recurrenceId())) {
+    for (auto it = events.cbegin(), end = events.cend(); it != end; ++it) {
+        if (!deleted || !cal->event((*it)->uid(), (*it)->recurrenceId())) {
             // use existing ones, or really deleted ones
             if (notebook.isEmpty() ||
-                    (!cal->notebook(*it2).isEmpty() && notebook.endsWith(cal->notebook(*it2)))) {
-                component = d->mImpl->writeEvent(*it2, tzlist, &tzUsedList);
+                    (!cal->notebook(*it).isEmpty() && notebook.endsWith(cal->notebook(*it)))) {
+                component = d->mImpl->writeEvent(*it, &tzUsedList);
                 icalcomponent_add_component(calendar, component);
+                ICalTimeZoneParser::updateTzEarliestDate((*it), &earliestTz);
             }
         }
     }
 
     // journals
     Journal::List journals = deleted ? cal->deletedJournals() : cal->rawJournals();
-    Journal::List::ConstIterator it3;
-    for (it3 = journals.constBegin(); it3 != journals.constEnd(); ++it3) {
-        if (!deleted || !cal->journal((*it3)->uid(), (*it3)->recurrenceId())) {
+    for (auto it = journals.cbegin(), end = journals.cend(); it != end; ++it) {
+        if (!deleted || !cal->journal((*it)->uid(), (*it)->recurrenceId())) {
             // use existing ones, or really deleted ones
             if (notebook.isEmpty() ||
-                    (!cal->notebook(*it3).isEmpty() && notebook.endsWith(cal->notebook(*it3)))) {
-                component = d->mImpl->writeJournal(*it3, tzlist, &tzUsedList);
+                    (!cal->notebook(*it).isEmpty() && notebook.endsWith(cal->notebook(*it)))) {
+                component = d->mImpl->writeJournal(*it, &tzUsedList);
                 icalcomponent_add_component(calendar, component);
+                ICalTimeZoneParser::updateTzEarliestDate((*it), &earliestTz);
             }
         }
     }
 
     // time zones
-    ICalTimeZones::ZoneMap zones = tzUsedList.zones();
     if (todoList.isEmpty() && events.isEmpty() && journals.isEmpty()) {
         // no incidences means no used timezones, use all timezones
         // this will export a calendar having only timezone definitions
-        zones = tzlist->zones();
+        tzUsedList = cal->d->mTimeZones;
     }
-    for (ICalTimeZones::ZoneMap::ConstIterator it = zones.constBegin();
-            it != zones.constEnd(); ++it) {
-        icaltimezone *tz = (*it).icalTimezone();
-        if (!tz) {
-            qCritical() << "bad time zone";
-        } else {
-            component = icalcomponent_new_clone(icaltimezone_get_component(tz));
-            icalcomponent_add_component(calendar, component);
-            icaltimezone_free(tz, 1);
+    for (const auto &qtz : qAsConst(tzUsedList)) {
+        if (qtz != QTimeZone::utc()) {
+            icaltimezone *tz = ICalTimeZoneParser::icaltimezoneFromQTimeZone(qtz, earliestTz[qtz]);
+            if (!tz) {
+                qCritical() << "bad time zone";
+            } else {
+                component = icalcomponent_new_clone(icaltimezone_get_component(tz));
+                icalcomponent_add_component(calendar, component);
+                icaltimezone_free(tz, 1);
+            }
         }
     }
 
@@ -332,7 +334,7 @@ QString ICalFormat::toString(const Calendar::Ptr &cal,
 
 QString ICalFormat::toICalString(const Incidence::Ptr &incidence)
 {
-    MemoryCalendar::Ptr cal(new MemoryCalendar(d->mTimeSpec));
+    MemoryCalendar::Ptr cal(new MemoryCalendar(d->mTimeZone));
     cal->addIncidence(Incidence::Ptr(incidence->clone()));
     return toString(cal.staticCast<Calendar>());
 }
@@ -344,26 +346,27 @@ QString ICalFormat::toString(const Incidence::Ptr &incidence)
 
 QByteArray ICalFormat::toRawString(const Incidence::Ptr &incidence)
 {
-    icalcomponent *component;
-    ICalTimeZones tzlist;
-    ICalTimeZones tzUsedList;
+    TimeZoneList tzUsedList;
 
-    component = d->mImpl->writeIncidence(incidence, iTIPRequest, &tzlist, &tzUsedList);
+    icalcomponent *component = d->mImpl->writeIncidence(incidence, iTIPRequest, &tzUsedList);
 
     QByteArray text = icalcomponent_as_ical_string(component);
 
+    TimeZoneEarliestDate earliestTzDt;
+    ICalTimeZoneParser::updateTzEarliestDate(incidence, &earliestTzDt);
+
     // time zones
-    ICalTimeZones::ZoneMap zones = tzUsedList.zones();
-    for (ICalTimeZones::ZoneMap::ConstIterator it = zones.constBegin();
-            it != zones.constEnd(); ++it) {
-        icaltimezone *tz = (*it).icalTimezone();
-        if (!tz) {
-            qCritical() << "bad time zone";
-        } else {
-            icalcomponent *tzcomponent = icaltimezone_get_component(tz);
-            icalcomponent_add_component(component, component);
-            text.append(icalcomponent_as_ical_string(tzcomponent));
-            icaltimezone_free(tz, 1);
+    for (const auto &qtz : qAsConst(tzUsedList)) {
+        if (qtz != QTimeZone::utc()) {
+            icaltimezone *tz = ICalTimeZoneParser::icaltimezoneFromQTimeZone(qtz, earliestTzDt[qtz]);
+            if (!tz) {
+                qCritical() << "bad time zone";
+            } else {
+                icalcomponent *tzcomponent = icaltimezone_get_component(tz);
+                icalcomponent_add_component(component, component);
+                text.append(icalcomponent_as_ical_string(tzcomponent));
+                icaltimezone_free(tz, 1);
+            }
         }
     }
 
@@ -374,8 +377,7 @@ QByteArray ICalFormat::toRawString(const Incidence::Ptr &incidence)
 
 QString ICalFormat::toString(RecurrenceRule *recurrence)
 {
-    icalproperty *property;
-    property = icalproperty_new_rrule(d->mImpl->writeRecurrenceRule(recurrence));
+    icalproperty *property = icalproperty_new_rrule(d->mImpl->writeRecurrenceRule(recurrence));
     QString text = QString::fromUtf8(icalproperty_as_ical_string(property));
     icalproperty_free(property);
     return text;
@@ -425,14 +427,13 @@ QString ICalFormat::createScheduleMessage(const IncidenceBase::Ptr &incidence,
 
             // Handle conversion to UTC times
             if (useUtcTimes) {
-                i->shiftTimes(KDateTime::Spec::UTC(), KDateTime::Spec::UTC());
+                i->shiftTimes(QTimeZone::utc(), QTimeZone::utc());
             }
 
             // Handle scheduling ID being present
             if (hasSchedulingId) {
                 // We have a separation of scheduling ID and UID
                 i->setSchedulingID(QString(), i->schedulingID());
-
             }
 
             // Build the message with the cloned incidence
@@ -454,8 +455,7 @@ FreeBusy::Ptr ICalFormat::parseFreeBusy(const QString &str)
 {
     clearException();
 
-    icalcomponent *message;
-    message = icalparser_parse_string(str.toUtf8().constData());
+    icalcomponent *message = icalparser_parse_string(str.toUtf8().constData());
 
     if (!message) {
         return FreeBusy::Ptr();
@@ -463,7 +463,7 @@ FreeBusy::Ptr ICalFormat::parseFreeBusy(const QString &str)
 
     FreeBusy::Ptr freeBusy;
 
-    icalcomponent *c;
+    icalcomponent *c = nullptr;
     for (c = icalcomponent_get_first_component(message, ICAL_VFREEBUSY_COMPONENT);
             c != nullptr; c = icalcomponent_get_next_component(message, ICAL_VFREEBUSY_COMPONENT)) {
         FreeBusy::Ptr fb = d->mImpl->readFreeBusy(c);
@@ -487,7 +487,7 @@ FreeBusy::Ptr ICalFormat::parseFreeBusy(const QString &str)
 ScheduleMessage::Ptr ICalFormat::parseScheduleMessage(const Calendar::Ptr &cal,
         const QString &messageText)
 {
-    setTimeSpec(cal->timeSpec());
+    setTimeZone(cal->timeZone());
     clearException();
 
     if (messageText.isEmpty()) {
@@ -496,8 +496,7 @@ ScheduleMessage::Ptr ICalFormat::parseScheduleMessage(const Calendar::Ptr &cal,
         return ScheduleMessage::Ptr();
     }
 
-    icalcomponent *message;
-    message = icalparser_parse_string(messageText.toUtf8().constData());
+    icalcomponent *message = icalparser_parse_string(messageText.toUtf8().constData());
 
     if (!message) {
         setException(
@@ -516,14 +515,12 @@ ScheduleMessage::Ptr ICalFormat::parseScheduleMessage(const Calendar::Ptr &cal,
     }
 
     // Populate the message's time zone collection with all VTIMEZONE components
-    ICalTimeZones tzlist;
-    ICalTimeZoneSource tzs;
-    tzs.parse(message, tzlist);
-
-    icalcomponent *c;
+    ICalTimeZoneCache tzlist;
+    ICalTimeZoneParser parser(&tzlist);
+    parser.parse(message);
 
     IncidenceBase::Ptr incidence;
-    c = icalcomponent_get_first_component(message, ICAL_VEVENT_COMPONENT);
+    icalcomponent *c = icalcomponent_get_first_component(message, ICAL_VEVENT_COMPONENT);
     if (c) {
         incidence = d->mImpl->readEvent(c, &tzlist).staticCast<IncidenceBase>();
     }
@@ -654,20 +651,19 @@ ScheduleMessage::Ptr ICalFormat::parseScheduleMessage(const Calendar::Ptr &cal,
     return ScheduleMessage::Ptr(new ScheduleMessage(incidence, method, status));
 }
 
-void ICalFormat::setTimeSpec(const KDateTime::Spec &timeSpec)
+void ICalFormat::setTimeZone(const QTimeZone &timeZone)
 {
-    d->mTimeSpec = timeSpec;
+    d->mTimeZone = timeZone;
 }
 
-KDateTime::Spec ICalFormat::timeSpec() const
+QTimeZone ICalFormat::timeZone() const
 {
-    return d->mTimeSpec;
+    return d->mTimeZone;
 }
 
-QString ICalFormat::timeZoneId() const
+QByteArray ICalFormat::timeZoneId() const
 {
-    KTimeZone tz = d->mTimeSpec.timeZone();
-    return tz.isValid() ? tz.name() : QString();
+    return d->mTimeZone.id();
 }
 
 void ICalFormat::virtual_hook(int id, void *data)
